@@ -45,8 +45,8 @@ def model_info(
     def transform(df: pd.DataFrame) -> pd.DataFrame:
         # Column mapping from DataFrame to ModelInfo field to read
         fields = {
-            "model_organization_name": "organization_name",
-            "model_display_name": "model_name",
+            "model_organization_name": "organization",
+            "model_display_name": "model",
             "model_snapshot": "snapshot",
             "model_release_date": "release_date",
             "model_knowledge_cutoff_date": "knowledge_cutoff_date",
