@@ -1,11 +1,12 @@
 from logging import getLogger
 from typing import TYPE_CHECKING, Any
 
-from openai import AsyncAzureOpenAI, AsyncOpenAI, BadRequestError
+from openai import AsyncAzureOpenAI, AsyncOpenAI, BadRequestError, NotGiven
 from openai._types import NOT_GIVEN
 from openai.types.responses import Response, ResponseFormatTextJSONSchemaConfigParam
 
 from inspect_ai._util.logger import warn_once
+from inspect_ai.model._providers._openai_batch import OpenAIBatcher
 from inspect_ai.tool import ToolChoice, ToolInfo
 
 from .._chat_message import ChatMessage
@@ -40,7 +41,9 @@ async def generate_responses(
     tool_choice: ToolChoice,
     config: GenerateConfig,
     service_tier: str | None,
+    user: str | NotGiven,
     openai_api: "OpenAIAPI",
+    batcher: OpenAIBatcher[Response] | None,
 ) -> ModelOutput | tuple[ModelOutput | Exception, ModelCall]:
     # allocate request_id (so we can see it from ModelCall)
     request_id = http_hooks.start_request()
@@ -72,6 +75,7 @@ async def generate_responses(
         else NOT_GIVEN,
         truncation="auto" if openai_api.is_computer_use_preview() else NOT_GIVEN,
         extra_headers={HttpxHooks.REQUEST_ID_HEADER: request_id},
+        user=user,
         **completion_params_responses(
             model_name,
             openai_api=openai_api,
@@ -83,7 +87,14 @@ async def generate_responses(
 
     try:
         # generate response
-        model_response: Response = await client.responses.create(**request)
+        model_response: Response = await (
+            batcher.generate_for_request(request)
+            if batcher
+            else client.responses.create(**request)
+        )
+        # model_response is `Response | Any`. The lazy type inference engine
+        # threw up its hands because of the `**request`.
+        assert isinstance(model_response, Response)
 
         # check for error
         if model_response.error is not None:
